constrainttools.GlobalConstraint
================================

.. inheritance-diagram:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint
   :private-bases:

.. autoclass:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.kind

   .. note:: Inherited from :py:class:`constrainttools._Constraint <abjad.tools.constrainttools._Constraint._Constraint._Constraint>`

.. autoattribute:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.predicate

   .. note:: Inherited from :py:class:`constrainttools._Constraint <abjad.tools.constrainttools._Constraint._Constraint._Constraint>`

Special Methods
---------------

.. automethod:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.__call__

.. automethod:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.__repr__

   .. note:: Inherited from :py:class:`constrainttools._Constraint <abjad.tools.constrainttools._Constraint._Constraint._Constraint>`

.. automethod:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.constrainttools.GlobalConstraint.GlobalConstraint.GlobalConstraint.__str__

   .. note:: Inherited from `__builtin__.object`
